# $Id: mt-renamelabel.pl 1705 2009-11-09 05:53:53Z sekine $

package MT::Plugin::RenameLabel;

use strict;
use MT::Plugin;
@MT::Plugin::RenameLabel::ISA = qw(MT::Plugin);

use MT::Util qw( dirify );

use vars qw($PLUGIN_NAME $VERSION);
$PLUGIN_NAME = 'RenameLabel';
$VERSION = '1.50';

use MT;
my $plugin = new MT::Plugin::RenameLabel({
    name => $PLUGIN_NAME,
    version => $VERSION,
    description => "This plugin allows you to change the labels of the fields on the entry editing screen.",
    doc_link => 'http://labs.m-logic.jp/plugins/mt-renamelabel/docs150/mt-renamelabel.html',
    author_name => 'M-Logic, Inc.',
    author_link => 'http://labs.m-logic.jp/',
    blog_config_template => \&template_mt6,
    settings => new MT::PluginSettings([
        ['rename_label_title'],
        ['rename_label_category'],
        ['rename_label_add_category'],
        ['rename_label_add_category_name'],
        ['rename_label_add_new_category_parent'],
        ['rename_label_make_primary'],
        ['rename_label_entry_body'],
        ['rename_label_extended_entry'],
        ['rename_label_excerpt'],
        ['rename_label_keywords'],
        ['rename_label_tags'],
        ['rename_label_status'],
        ['rename_label_publish_date'],
        ['rename_label_text_formatting'],
        ['rename_label_basename'],
        ['rename_label_accept'],
        ['rename_label_accept_comments'],
        ['rename_label_accept_trackbacks'],
        ['rename_label_outbound_trackback_urls'],
        ['rename_label_comments'],
        ['rename_label_trackbacks'],
        ['rename_label_publishing'],
        ['rename_label_assets'],
        ['rename_label_change_note'],
        ['rename_label_unpublish_date'],
        ['rename_label_entry_assets'],

        ['rename_label_page_title'],
        ['rename_label_page_folder'],
        ['rename_label_page_add_folder'],
        ['rename_label_page_change_folder'],
        ['rename_label_page_entry_body'],
        ['rename_label_page_extended_entry'],
        ['rename_label_page_excerpt'],
        ['rename_label_page_keywords'],
        ['rename_label_page_tags'],
        ['rename_label_page_status'],
        ['rename_label_page_publish_date'],
        ['rename_label_page_text_formatting'],
        ['rename_label_page_filename'],
        ['rename_label_page_accept'],
        ['rename_label_page_accept_comments'],
        ['rename_label_page_accept_trackbacks'],
        ['rename_label_page_outbound_trackback_urls'],
        ['rename_label_page_comments'],
        ['rename_label_page_trackbacks'],
        ['rename_label_page_publishing'],
        ['rename_label_page_assets'],
        ['rename_label_page_change_note'],
        ['rename_label_page_unpublish_date'],
    ]),
});

if (MT->version_number >= 6) {
    MT->add_plugin($plugin);
    MT->add_callback('template_source.edit_entry', 9, $plugin, \&hdlr_edit_entry_mt6_source);
    MT->add_callback('template_param.edit_entry', 9, $plugin, \&hdlr_edit_entry_mt6_param);
}

my @labels_mt6 = (
                "Title",
                "Category",
                "Add category",
                "Add category name",
                "Add new category parent",
                "Make primary",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Unpublish Date",
                "Text Formatting",
                "Basename",
                "Accept",
                "Comments",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                "Publishing",
                "Change note",
                [ "[_1] Assets", "Entry", "rename_label_entry_assets" ],
                );

my @labels_mt6_page = (
                "Title",
                "Folder",
                "Add folder",
                "Change Folder",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Unpublish Date",
                "Text Formatting",
                "Filename",
                "Accept",
                "Comments",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                "Publishing",
                "Change note",
                [ "[_1] Assets", "Page", "rename_label_page_assets" ],
                );

my @labels_mt61 = (
                "Title",
                "Category",
                "Add category",
                "Add new category parent",
                "Make primary",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Unpublish Date",
                "Text Formatting",
                "Basename",
                "Accept",
                "Comments",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                "Publishing",
                "Change note",
                [ "[_1] Assets", "Entry", "rename_label_entry_assets" ],
                );

sub instance { $plugin; }

sub is_mt6 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 2) eq '6.' ? 1 : 0;
}

sub is_mt60 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '6.0' ? 1 : 0;
}

sub is_mt61 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '6.1' ? 1 : 0;
}

sub is_mt62 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '6.2' ? 1 : 0;
}

sub make_field_mt51 {
    my ($label, $id, $params) = @_;
    if ($params) {
        $params = ' params="<__trans phrase="' . $params . '">"';
    }
    my $tmpl;
    $tmpl .= '<div id="' . $id . '-field" class="field field-left-label pkg ">' . "\n";
    $tmpl .= '<div class="field-header">' . "\n";
    $tmpl .= '<label for="' . $id . '"><__trans phrase="' . $label . '"' . $params . '>:</label>' . "\n";
    $tmpl .= '</div>' . "\n";
    $tmpl .= '<div class="field-content ">' . "\n";
    $tmpl .= '<p><input type="text" name="' . $id . '" id="' . $id . '" value="<mt:var name=' . uc ($id) . ' escape="html">" /></p>' . "\n";
    $tmpl .= '</div> ' . "\n";
    $tmpl .= '</div>' . "\n";

    $tmpl;
}

sub template_mt6 {
    my $tmpl;

    $tmpl .= '<h4><MT_TRANS phrase="Entry"></h4>' . "\n";
    my @labels = is_mt60() ? @labels_mt6 : @labels_mt61;
    for my $label (@labels) {
        my $params = '';
        my $id;
        if (ref $label eq 'ARRAY') {
            ($label, $params, $id) = @$label;
        }
        else {
            $id = 'rename_label_' . dirify($label);
        }
        $tmpl .= make_field_mt51($label, $id, $params);
    }

    $tmpl .= '<h4><MT_TRANS phrase="Pages"></h4>' . "\n";
    for my $label (@labels_mt6_page) {
        my $params = '';
        my $id;
        if (ref $label eq 'ARRAY') {
            ($label, $params, $id) = @$label;
        }
        else {
            $id = 'rename_label_page_' . dirify($label);
        }
        $tmpl .= make_field_mt51($label, $id, $params);
    }

    $tmpl;
}

sub get_data {
    my $plugin = shift;
    my ($blog_id, $field) = @_;
    my %plugin_param;

    my $field_name = 'rename_label_' . $field;

    $plugin->load_config(\%plugin_param, 'blog:'.$blog_id);
    my $key = $plugin_param{$field_name};
    unless ($key) {
        $plugin->load_config(\%plugin_param, 'system');
        $key = $plugin_param{$field_name};
    }
    $key;
}

sub transform_mt51_entry {
    my ($eh, $app, $tmpl_ref) = @_;

    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my $old;
    my $new;
    my $new_label;

  if ($new_label = $plugin->get_data($blog_id, 'title')) {
    $old = quotemeta('<__trans phrase="Title">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'status')) {
    $old = quotemeta('<__trans phrase="Status">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'entry_body')) {
    $old = quotemeta('<__trans phrase="Body">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'extended_entry')) {
    $old = quotemeta('<__trans phrase="Extended">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'excerpt')) {
    $old = quotemeta(<<'HTML');
       label="$field_label"
       label_class="top-label"
       help_page="entries"
       help_section="excerpt">
HTML
    $new = <<"HTML";
       label="$new_label"
       label_class="top-label"
       help_page="entries"
       help_section="excerpt">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'keywords')) {
    $old = quotemeta(<<'HTML');
       label="$field_label"
       label_class="top-label"
       help_page="entries"
       help_section="keywords">
HTML
    $new = <<"HTML";
       label="$new_label"
       label_class="top-label"
       help_page="entries"
       help_section="keywords">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'tags')) {
    $old = quotemeta('<__trans phrase="Tags">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'text_formatting')) {
    $old = quotemeta('<__trans phrase="Format:">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'outbound_trackback_urls')) {
    $old = quotemeta('<__trans phrase="Outbound TrackBack URLs">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'publish_date')) {
    $old = quotemeta('<__trans phrase="Publish On">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
    $old = quotemeta('<__trans phrase="Publish Date">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'category')) {
    $old = quotemeta('<__trans phrase="Categories">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'basename')) {
    $old = quotemeta('<__trans phrase="Basename">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept_comments')) {
    $old = quotemeta('<__trans phrase="Accept Comments">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept_trackbacks')) {
    $old = quotemeta('<__trans phrase="Accept Trackbacks">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'comments')) {
    $old = quotemeta('<__trans phrase="Comments">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'trackbacks')) {
    $old = quotemeta('<__trans phrase="TrackBacks">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_category')) {
    $old = quotemeta('<__trans phrase="Add category">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_category_name')) {
    $old = quotemeta('<__trans phrase="Add category name">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_new_category_parent')) {
    $old = quotemeta('<__trans phrase="Add new category parent">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'make_primary')) {
    $old = quotemeta('[#|h trans("Make primary") #]');
    $new = '[#|h trans("' . $new_label . '") #]';
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'publishing')) {
    $old = quotemeta('<__trans phrase="Publishing">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'change_note')) {
    $old = quotemeta('<__trans phrase="Change note">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'entry_assets')) {
      $old = quotemeta('<__trans phrase="[_1] Assets" params="<mt:var name="object_label">">');
      $new = $new_label;
      $$tmpl_ref =~ s!$old!$new!g;
  }
}

sub transform_mt51_page {
    my ($eh, $app, $tmpl_ref) = @_;

    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my $old;
    my $new;
    my $new_label;

  if ($new_label = $plugin->get_data($blog_id, 'page_title')) {
    $old = quotemeta('<__trans phrase="Title">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_status')) {
    $old = quotemeta('<__trans phrase="Status">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_entry_body')) {
    $old = quotemeta('<__trans phrase="Body">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_extended_entry')) {
    $old = quotemeta('<__trans phrase="Extended">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_excerpt')) {
    $old = quotemeta(<<'HTML');
       label="$field_label"
       label_class="top-label"
       help_page="entries"
       help_section="excerpt">
HTML
    $new = <<"HTML";
       label="$new_label"
       label_class="top-label"
       help_page="entries"
       help_section="excerpt">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_keywords')) {
    $old = quotemeta(<<'HTML');
       label="$field_label"
       label_class="top-label"
       help_page="entries"
       help_section="keywords">
HTML
    $new = <<"HTML";
       label="$new_label"
       label_class="top-label"
       help_page="entries"
       help_section="keywords">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_tags')) {
    $old = quotemeta('<__trans phrase="Tags">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_text_formatting')) {
    $old = quotemeta('<__trans phrase="Format:">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_outbound_trackback_urls')) {
    $old = quotemeta('<__trans phrase="Outbound TrackBack URLs">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_publish_date')) {
    $old = quotemeta('<__trans phrase="Publish On">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
    $old = quotemeta('<__trans phrase="Publish Date">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_folder')) {
    $old = quotemeta('<__trans phrase="Folder">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_filename')) {
    $old = quotemeta('<__trans phrase="Filename">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept_comments')) {
    $old = quotemeta('<__trans phrase="Accept Comments">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept_trackbacks')) {
    $old = quotemeta('<__trans phrase="Accept Trackbacks">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_comments')) {
    $old = quotemeta('<__trans phrase="Comments">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_trackbacks')) {
    $old = quotemeta('<__trans phrase="TrackBacks">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept')) {
    $old = quotemeta('<__trans phrase="Accept"/>');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_add_folder')) {
    $old = quotemeta('<__trans phrase="Add folder">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_change_folder')) {
    $old = quotemeta('<__trans phrase="Change Folder"/>');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_publishing')) {
    $old = quotemeta('<__trans phrase="Publishing">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_change_note')) {
    $old = quotemeta('<__trans phrase="Change note">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_assets')) {
      $old = quotemeta('<__trans phrase="[_1] Assets" params="<mt:var name="object_label">">');
      $new = $new_label;
      $$tmpl_ref =~ s!$old!$new!g;
  }
}


sub hdlr_edit_entry_mt51_source {
    my ($eh, $app, $tmpl_ref) = @_;
    my $q = $app->{'query'};

    if ($q->param('_type') eq 'entry') {
        transform_mt51_entry(@_);
    } elsif ($q->param('_type') eq 'page') {
        transform_mt51_page(@_);
    }
    1;
}

sub hdlr_edit_entry_mt51_param {
    my ($cb, $app, $param, $tmpl) = @_;
    my $q = $app->{'query'};
    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my %dic = (
        'title' => 'title',
        'text' => 'entry_body',
        'tags' => 'tags',
        'excerpt' => 'excerpt',
        'keywords' => 'keywords',
    );
    my %rename_dic = ();
    for my $key ( keys %dic ) {
        my $new_label;
        if ($q->param('_type') eq 'entry') {
            if ($new_label = $plugin->get_data($blog_id, $dic{$key})) {
                $rename_dic{$key} = $new_label;
            }
        } elsif ($q->param('_type') eq 'page') {
            if ($new_label = $plugin->get_data($blog_id, 'page_' . $dic{$key})) {
                $rename_dic{$key} = $new_label;
            }
        }
    }
    my @fields;
    for my $field (@{$param->{field_loop}}) {
        my $name = $field->{field_name};
        if ($rename_dic{$name}) {
            $field->{field_label} = $rename_dic{$name};
        }
        push (@fields, $field);
    }

    $param->{field_loop} = \@fields;
}

# For MT6
sub hdlr_edit_entry_mt6_source {
    my ($eh, $app, $tmpl_ref) = @_;

    hdlr_edit_entry_mt51_source(@_);

    my $blog_id = $app->blog->id;
    my $q = $app->{'query'};
    my $new_label;
    if ($q->param('_type') eq 'entry') {
        $new_label = $plugin->get_data($blog_id, 'unpublish_date');
    }
    else {
        $new_label = $plugin->get_data($blog_id, 'page_unpublish_date');
    }
    if ($new_label) {
        my $old_label = quotemeta('<__trans phrase="Unpublish Date">');
        $$tmpl_ref =~ s!$old_label!$new_label!g;
    }

    return 1;
}

sub hdlr_edit_entry_mt6_param {
    my ($cb, $app, $param, $tmpl) = @_;
    hdlr_edit_entry_mt51_param(@_);
}

1;

